#include "stdafx.h"
#include "csub.h"

CString GetStartupDirectory()
{
	CString dir;
	SHGetSpecialFolderPath(NULL, dir.GetBuffer(MAX_PATH), CSIDL_STARTUP, FALSE);	
	dir.ReleaseBuffer();
	return dir;
}

CString GetAppDataDirectory()
{
	CString dir;
	ExpandEnvironmentStrings(_T("%APPDATA%"), dir.GetBuffer(MAX_PATH), MAX_PATH);
	dir.ReleaseBuffer();
	return dir;
}

void ForceDirectory(const TCHAR *path)
{
	int pos;
	TCHAR dir[MAX_PATH];

	pos = 0;
	while(*(path + pos) != _T('\0')) {
		if(*(path + pos) == _T('\\')) {
			dir[pos] = _T('\0');
			CreateDirectory(dir, NULL);
		}
		dir[pos] = *(path + pos);
		pos++;
	}
	CreateDirectory(path, NULL);
}


CString ExtractName(CString name)
{
	int pos = name.ReverseFind(_T('.'));
	if(pos != -1) {
		return name.Left(pos);
	}
	return name;
}

CString ExtractFileName(CString name)
{
	int pos = name.ReverseFind(_T('\\'));
	if(pos != -1) {
		return name.Mid(pos + 1);
	}
	return name;
}

CString ExtractDirectory(CString name)
{
	int start = -1;
	for(int pos = 0 ; pos < name.GetLength() ; pos++) {
		if(name[pos] == _T('\\')) {
			start = pos;
		}
	}
	if(start != -1) {
		return name.Left(start);
	}
	return _T("");
}

bool CreateShortcut(const CString name, const CString link, bool link_dir_flag)
{
	bool flag = false;
	HRESULT result;
	IShellLink* pShellLink;
	CString path;

	result = CoCreateInstance(CLSID_ShellLink, NULL, CLSCTX_INPROC_SERVER, IID_IShellLink, (void**)&pShellLink);
	if(SUCCEEDED(result)) {
		IPersistFile* pPersistFile;
		result = pShellLink->QueryInterface(IID_IPersistFile, (void**)&pPersistFile);
		if(SUCCEEDED(result)) {
			result = pShellLink->SetPath(name);
			if(SUCCEEDED(result)) {
				if(link_dir_flag) {
					path = ExtractDirectory(link);
				} else {
					path = ExtractDirectory(name);
				}
				result = pShellLink->SetWorkingDirectory(path);
				if(SUCCEEDED(result)) {
					result = pPersistFile->Save(link, TRUE);
					if(SUCCEEDED(result)) {
						flag = true;
					}
				}
			}
			pPersistFile->Release();
		}
		pShellLink->Release();
	}
	return flag;
}

CString GetString(int id)
{
	CString str;
	str.LoadString(id);
	return str;
}

